@@ -7,7 +7,7 @@ class Orders(Base):
     RESOURCE_ID_PREFIX = 'ord_'
 
     def get_resource_object(self, result):
-        return Order(result, client=self.client)
+        return Order(result, self.client)
 
     def get(self, order_id, **params):
         if not order_id or not order_id.startswith(self.RESOURCE_ID_PREFIX):
